@@ -2158,6 +2158,8 @@ class Trimesh(Geometry3D):
                     plane_origin,
                     plane_normal,
                     cap=False,
+                    face_index=None,
+                    cached_dots=None,
                     **kwargs):
         """
         Slice the mesh with a plane, returning a new mesh that is the
@@ -2169,6 +2171,9 @@ class Trimesh(Geometry3D):
           Normal vector of plane to intersect with mesh
         cap : bool
           If True, cap the result with a triangulated polygon
+        face_index : ((m,) int)
+            Indexes of mesh.faces to slice. When no mask is
+            provided, the default is to slice all faces.
         cached_dots : (n, 3) float
             If an external function has stored dot
             products pass them here to avoid recomputing
@@ -2186,6 +2191,8 @@ class Trimesh(Geometry3D):
             plane_normal=plane_normal,
             plane_origin=plane_origin,
             cap=cap,
+            face_index=face_index,
+            cached_dots=cached_dots,
             **kwargs)
 
         return new_mesh
@@ -2495,6 +2502,48 @@ class Trimesh(Geometry3D):
         return Path3D(**faces_to_path(
             self, face_ids, **kwargs))
 
+    def projected(self,
+                  normal,
+                  **kwargs):
+        """
+        Project a mesh onto a plane and then extract the
+        polygon that outlines the mesh projection on that
+        plane.
+
+        Parameters
+        ----------
+        mesh : trimesh.Trimesh
+          Source geometry
+        check : bool
+          If True make sure is flat
+        normal : (3,) float
+          Normal to extract flat pattern along
+        origin : None or (3,) float
+          Origin of plane to project mesh onto
+        pad : float
+          Proportion to pad polygons by before unioning
+          and then de-padding result by to avoid zero-width gaps.
+        tol_dot : float
+          Tolerance for discarding on-edge triangles.
+        max_regions : int
+          Raise an exception if the mesh has more than this
+          number of disconnected regions to fail quickly before unioning.
+
+        Returns
+        ----------
+        projected : trimesh.path.Path2D
+          Outline of source mesh
+        """
+        from .path import Path2D
+        from .exchange.load import load_path
+        from .path.polygons import projected
+
+        projection = projected(
+            mesh=self, normal=normal, **kwargs)
+        if projection is None:
+            return Path2D()
+        return load_path(projection)
+
     @caching.cache_decorator
     def area(self):
         """
@@ -2518,8 +2567,9 @@ class Trimesh(Geometry3D):
         area_faces : (n, ) float
           Area of each face
         """
-        area_faces = triangles.area(crosses=self.triangles_cross,
-                                    sum=False)
+        area_faces = triangles.area(
+            crosses=self.triangles_cross,
+            sum=False)
         return area_faces
 
     @caching.cache_decorator
