@@ -64,9 +64,11 @@ def face_adjacency(faces=None,
     ----------
     This is useful for lots of things such as finding
     face- connected components:
+    ```python
     >>> graph = nx.Graph()
     >>> graph.add_edges_from(mesh.face_adjacency)
     >>> groups = nx.connected_components(graph_connected)
+    ```
     """
 
     if mesh is None:
@@ -165,20 +167,20 @@ def face_adjacency_radius(mesh):
     Returns
     -------------
     radii : (len(self.face_adjacency),) float
-        Approximate radius between faces
-        Parallel faces will have a value of np.inf
+      Approximate radius between faces
+      Parallel faces will have a value of np.inf
     span :  (len(self.face_adjacency),) float
-        Perpendicular projection distance of two
-        unshared vertices onto the shared edge
+      Perpendicular projection distance of two
+      unshared vertices onto the shared edge
     """
 
     # solve for the radius of the adjacent faces
-    #         distance
-    # R = ------------------
-    #     2 * sin(theta / 2)
+    #       distance
+    # R = ---------------
+    #     2 * sin(theta)
     nonzero = mesh.face_adjacency_angles > np.radians(.01)
     denominator = np.abs(
-        2.0 * np.sin(mesh.face_adjacency_angles[nonzero] / 1.0))
+        2.0 * np.sin(mesh.face_adjacency_angles[nonzero]))
 
     # consider the distance between the non- shared vertices of the
     # face adjacency pair as the key distance
@@ -749,7 +751,7 @@ def neighbors(edges, max_index=None, directed=False):
     return array
 
 
-def smoothed(mesh, angle=None, facet_minarea=15):
+def smoothed(mesh, angle=None, facet_minarea=10):
     """
     Return a non- watertight version of the mesh which
     will render nicely with smooth shading by
@@ -773,14 +775,14 @@ def smoothed(mesh, angle=None, facet_minarea=15):
       Geometry with disconnected face patches
     """
     if angle is None:
-        angle = np.radians(30)
+        angle = np.radians(20)
 
     # if the mesh has no adjacent faces return a copy
     if len(mesh.face_adjacency) == 0:
         return mesh.copy()
 
     # face pairs below angle threshold
-    angle_ok = mesh.face_adjacency_angles <= angle
+    angle_ok = mesh.face_adjacency_angles < angle
     # subset of face adjacency
     adjacency = mesh.face_adjacency[angle_ok]
 
@@ -803,8 +805,7 @@ def smoothed(mesh, angle=None, facet_minarea=15):
                                dtype=bool)
                 mask[np.hstack(facets)] = False
                 # apply the mask to adjacency
-                adjacency = adjacency[
-                    mask[adjacency].all(axis=1)]
+                adjacency = adjacency[mask[adjacency].all(axis=1)]
                 # nodes are no longer every faces
                 nodes = np.unique(adjacency)
         except BaseException:
@@ -813,7 +814,7 @@ def smoothed(mesh, angle=None, facet_minarea=15):
     # run connected components on facet adjacency
     components = connected_components(
         adjacency,
-        min_len=1,
+        min_len=2,
         nodes=nodes)
 
     # add back coplanar groups if any exist
