@@ -275,7 +275,10 @@ def _svg_path_convert(paths, force=None):
 
     for attrib, matrix in paths:
         # the path string is stored under `d`
-        path_string = attrib['d']
+        path_string = attrib.get('d', '')
+        if len(path_string) == 0:
+            log.warning('empty path string!')
+            continue
 
         # get the name of the geometry if trimesh specified it
         # note that the get will by default return `None`
@@ -569,11 +572,66 @@ def _encode(stuff):
     result = 'base64,' + util.decode_text(pack)
     if tol.strict:
         # make sure we haven't broken the things
-        assert _decode(result) == stuff
+        _deep_same(stuff, _decode(result))
 
     return result
 
 
+def _deep_same(original, other):
+    """
+    Do a recursive comparison of two items to check
+    our encoding scheme in unit tests.
+
+    Parameters
+    -----------
+    original : str, bytes, list, dict
+      Original item
+    other : str, bytes, list, dict
+      Item that should be identical
+
+    Raises
+    ------------
+    AssertionError
+      If items are not the same.
+    """
+    # ndarrays will be converted to lists
+    # but otherwise types should be identical
+    if isinstance(original, np.ndarray):
+        assert isinstance(other, (list, np.ndarray))
+    elif util.is_string(original):
+        # handle python 2+3 unicode vs str
+        assert util.is_string(other)
+    else:
+        # otherwise they should be the same type
+        assert isinstance(original, type(other))
+
+    if isinstance(original, (str, bytes)):
+        # string and bytes should just be identical
+        assert original == other
+        return
+    elif isinstance(original, (float, int, np.ndarray)):
+        # for numeric classes use numpy magic comparison
+        # which includes an epsilon for floating point
+        assert np.allclose(original, other)
+        return
+    elif isinstance(original, list):
+        # lengths should match
+        assert len(original) == len(other)
+        # every element should be identical
+        for a, b in zip(original, other):
+            _deep_same(a, b)
+        return
+
+    # we should have special-cased everything else by here
+    assert isinstance(original, dict)
+
+    # all keys should match
+    assert set(original.keys()) == set(other.keys())
+    # do a recursive comparison of the values
+    for k in original.keys():
+        _deep_same(original[k], other[k])
+
+
 def _decode(bag):
     """
     Decode a base64 bag of stuff.
