@@ -94,10 +94,14 @@ def enclosure_tree(polygons):
     if len(degrees) > 0 and degrees.max() > 1:
         # collect new edges for graph
         edges = []
+
+        # order the roots so they are sorted by degree
+        roots = roots[np.argsort([degree[r] for r in roots])]
         # find edges of subgraph for each root and children
         for root in roots:
             children = indexes[degrees == degree[root] + 1]
-            edges.extend(contains.subgraph(np.append(children, root)).edges())
+            edges.extend(contains.subgraph(
+                np.append(children, root)).edges())
         # stack edges into new directed graph
         contains = nx.from_edgelist(edges, nx.DiGraph())
         # if roots have no children add them anyway
@@ -668,13 +672,23 @@ def repair_invalid(polygon, scale=None, rtol=.5):
 def projected(mesh,
               normal,
               origin=None,
-              pad=1e-5,
+              rpad=1e-5,
+              apad=None,
               tol_dot=0.01,
               max_regions=200):
     """
     Project a mesh onto a plane and then extract the polygon
     that outlines the mesh projection on that plane.
 
+    Note that this will ignore back-faces, which is only
+    relevant if the source mesh isn't watertight.
+
+    Also padding: this generates a result by unioning the
+    polygons of multiple connected regions, which requires
+    the polygons be padded by a distance so that a polygon
+    union produces a single coherent result. This distance
+    is calculated as: `apad + (rpad * scale)`
+
     Parameters
     ----------
     mesh : trimesh.Trimesh
@@ -685,18 +699,22 @@ def projected(mesh,
       Normal to extract flat pattern along
     origin : None or (3,) float
       Origin of plane to project mesh onto
-    pad : float
+    rpad : float
       Proportion to pad polygons by before unioning
       and then de-padding result by to avoid zero-width gaps.
+    apad : float
+      Absolute padding to pad polygons by before unioning
+      and then de-padding result by to avoid zero-width gaps.
     tol_dot : float
       Tolerance for discarding on-edge triangles.
     max_regions : int
       Raise an exception if the mesh has more than this
-      number of disconnected regions to fail quickly before unioning.
+      number of disconnected regions to fail quickly before
+      unioning.
 
     Returns
     ----------
-    projected : shapely.geometry.Polygon
+    projected : shapely.geometry.Polygon or None
       Outline of source mesh
 
     Raises
@@ -710,23 +728,28 @@ def projected(mesh,
 
     # the projection of each face normal onto facet normal
     dot_face = np.dot(normal, mesh.face_normals.T)
-    # check if face lies on front or back of normal
-    front = dot_face > tol_dot
-    back = dot_face < -tol_dot
-    # divide the mesh into front facing section and back facing parts
-    # and discard the faces perpendicular to the axis.
-    # since we are doing a unary_union later we can use the front *or*
-    # the back so we use which ever one has fewer triangles
-    # we want the largest nonzero group
-    count = np.array([front.sum(), back.sum()])
-    if count.min() == 0:
-        # if one of the sides has zero faces we need the other
-        pick = count.argmax()
+    if mesh.is_watertight:
+        # for watertight mesh, speed up projection by handling side with less faces
+        # check if face lies on front or back of normal
+        front = dot_face > tol_dot
+        back = dot_face < -tol_dot
+        # divide the mesh into front facing section and back facing parts
+        # and discard the faces perpendicular to the axis.
+        # since we are doing a unary_union later we can use the front *or*
+        # the back so we use which ever one has fewer triangles
+        # we want the largest nonzero group
+        count = np.array([front.sum(), back.sum()])
+        if count.min() == 0:
+            # if one of the sides has zero faces we need the other
+            pick = count.argmax()
+        else:
+            # otherwise use the normal direction with the fewest faces
+            pick = count.argmin()
+        # use the picked side
+        side = [front, back][pick]
     else:
-        # otherwise use the normal direction with the fewest faces
-        pick = count.argmin()
-    # use the picked side
-    side = [front, back][pick]
+        # for non-watertight mesh, only handle the front side of normal
+        side = dot_face > tol_dot
 
     # subset the adjacency pairs to ones which have both faces included
     # on the side we are currently looking at
@@ -761,6 +784,16 @@ def projected(mesh,
         polygons.extend(edges_to_polygons(
             edges=edge[group], vertices=vertices_2D))
 
+    padding = 0.0
+    if apad is not None:
+        # set padding by absolute value
+        padding += float(apad)
+    if rpad is not None:
+        # get the 2D scale as the longest side of the AABB
+        scale = vertices_2D.ptp(axis=0).max()
+        # apply the scale-relative padding
+        padding += float(rpad) * scale
+
     # some types of errors will lead to a bajillion disconnected
     # regions and the union will take forever to fail
     # so exit here early
@@ -769,21 +802,13 @@ def projected(mesh,
 
     # if there is only one region we don't need to run a union
     elif len(polygons) == 1:
-        polygon = polygons[0]
-        # we do however need to double buffer to de-garbage the polygon
-        scale = np.reshape(polygon.bounds, (2, 2)).ptp(axis=0).max()
-        padding = scale * pad
-        polygon = polygon.buffer(padding).buffer(-padding)
+        polygon = polygons[0].buffer(padding).buffer(-padding)
+    elif len(polygons) == 0:
+        return None
     else:
-        # get all points for every AABB
-        extrema = np.reshape([p.bounds for p in polygons], (-1, 2))
-        # extract the model scale from the maximum AABB side length
-        scale = extrema.ptp(axis=0).max()
-        # pad each polygon proportionally to that scale
-        distance = abs(scale * pad)
         # inflate each polygon before unioning to remove zero-size
         # gaps then deflate the result after unioning by the same amount
         polygon = ops.unary_union(
-            [p.buffer(distance) for p in polygons]).buffer(-distance)
+            [p.buffer(padding) for p in polygons]).buffer(-padding)
 
     return polygon
